# from https://dev.infobip.com/v1/docs/response-codes#status-object-example 2016-10-03

import json
from pkg_resources import resource_filename

with open(resource_filename(__name__, 'hsi/merged.json')) as f:
    hsis = json.loads(f.read())

status_group = {
                 0: {'groupName': 'ACCEPTED', 'description': 'Message is accepted.'},
                 1: {'groupName': 'PENDING', 'description': 'Message is in pending status.'},
                 2: {'groupName': 'UNDELIVERABLE', 'description': 'Message is undeliverable.'},
                 3: {'groupName': 'DELIVERED', 'description': 'Message is delivered.'},
                 4: {'groupName': 'EXPIRED', 'description': 'Message is expired.'},
                 5: {'groupName': 'REJECTED', 'description': 'Message is rejected.'}
               }

status_id = {
          0: {'groupId': 0, 'name': 'MESSAGE_ACCEPTED', 'description': 'Message accepted', 'action': None},
          1: {'groupId': 1, 'name': 'PENDING_TIME_VIOLATION', 'description': 'Time window violation', 'action': None},
          2: {'groupId': 3, 'name': 'DELIVERED_TO_OPERATOR', 'description': 'Message delivered to operator', 'action': None},
          3: {'groupId': 1, 'name': 'PENDING_WAITING_DELIVERY', 'description': 'Message sent, waiting for delivery report', 'action': None},
          4: {'groupId': 2, 'name': 'UNDELIVERABLE_REJECTED_OPERATOR', 'description': 'Message rejected by operator', 'action': None},
          5: {'groupId': 3, 'name': 'DELIVERED_TO_HANDSET', 'description': 'Message delivered to handset', 'action': None},
          6: {'groupId': 5, 'name': 'REJECTED_NETWORK', 'description': 'Network is forbidden', 'action': 'Contact account manager'},
          7: {'groupId': 1, 'name': 'PENDING_ENROUTE', 'description': 'Message sent to next instance', 'action': None}, # this is actual, docs says 'Message submitted to operator'
          8: {'groupId': 5, 'name': 'REJECTED_PREFIX_MISSING', 'description': 'Number prefix missing', 'action': None},
          9: {'groupId': 2, 'name': 'UNDELIVERABLE_NOT_DELIVERED', 'description': 'Message sent not delivered', 'action': None},
          10: {'groupId': 5, 'name': 'REJECTED_DND', 'description': 'Destination on DND list', 'action': None},
          11: {'groupId': 5, 'name': 'REJECTED_SOURCE', 'description': 'Invalid Source address', 'action': None},
          12: {'groupId': 5, 'name': 'REJECTED_NOT_ENOUGH_CREDITS', 'description': 'Not enough credits', 'action': None},
          13: {'groupId': 5, 'name': 'REJECTED_SENDER', 'description': 'Rejected by Sender', 'action': 'Remove sender from blacklist'},
          14: {'groupId': 5, 'name': 'REJECTED_DESTINATION', 'description': 'Rejected by Destination', 'action': 'Remove destination from blacklist'},
          15: {'groupId': 4, 'name': 'EXPIRED_EXPIRED', 'description': 'Message expired', 'action': None},
          16: {'groupId': 5, 'name': 'REJECTED_NOT_REACHABLE', 'description': 'Network not reachable', 'action': None},
          17: {'groupId': 5, 'name': 'REJECTED_PREPAID_PACKAGE_EXPIRED', 'description': 'Prepaid package expired', 'action': 'Top-Up your account to extend the validty period'},
          18: {'groupId': 5, 'name': 'REJECTED_DESTINATION_NOT_REGISTERED', 'description': 'Destination not registered', 'action': None},
          19: {'groupId': 5, 'name': 'REJECTED_ROUTE_NOT_AVAILABLE', 'description': 'Route not available', 'action': 'Contact account manager'},
          20: {'groupId': 5, 'name': 'REJECTED_FLOODING_FILTER', 'description': 'Rejected flooding', 'action': 'STOP SPAMMING'},
          21: {'groupId': 5, 'name': 'REJECTED_SYSTEM_ERROR', 'description': 'System error', 'action': 'Try again'},
          22: {'groupId': 4, 'name': 'EXPIRED_UNKNOWN', 'description': 'Unknown Reason', 'action': None},
          23: {'groupId': 5, 'name': 'REJECTED_DUPLICATE_MESSAGE_ID', 'description': 'Rejected duplicate message ID', 'action': None},
          24: {'groupId': 5, 'name': 'REJECTED_INVALID_UDH', 'description': 'Rejected invalid UDH', 'action': None},
          25: {'groupId': 5, 'name': 'REJECTED_MESSAGE_TOO_LONG', 'description': 'If message is split into more than 25 parts or message text exceeds 4000 bytes ', 'action': None}, # shouldn't action be: make msg shorter?
          26: {'groupId': 1, 'name': 'PENDING_ACCEPTED', 'description': 'Message accepted, pending for delivery', 'action': None},
          27: {'groupId': 1, 'name': 'PENDING_APPROVAL', 'description': 'Message accepted, pending for approval', 'action': None},
          28: {'groupId': 5, 'name': 'REJECTED_NOT_SENT', 'description': 'Rejected Not Sent', 'action': None},
          29: {'groupId': 4, 'name': 'EXPIRED_DLR_UNKNOWN', 'description': 'Expired DLR Unknown', 'action': None},
          30: {'groupId': 2, 'name': 'DELIVERED', 'description': 'MO forwarded and delivered', 'action': None},
          31: {'groupId': 2, 'name': 'UNDELIVERABLE_NOT_SENT', 'description': 'Message not sent', 'action': None},
          51: {'groupId': 5, 'name': 'MISSING_TO', 'description':'Missing destination', 'action': 'Check to parameter.'},
          52: {'groupId': 5, 'name': 'REJECTED_INVALID_DESTINATION', 'description': 'Invalid destination address.', 'action': 'Check to parameter.'},
          53: {'groupId': 5, 'name': 'REJECTED_INVALID_AUDIO_FILE_URL', 'description': 'Invalid audioFileUrl', 'action': None},
          54: {'groupId': 5, 'name': 'REJECTED_UNSUPPORTED_LANGUAGE', 'description': 'Unsupported language',  'action': None},
          55: {'groupId': 5, 'name': 'REJECTED_MESSAGE_IS_EMPTY', 'description': 'Message text is empty', 'action': None},
          56: {'groupId': 5, 'name': 'REJECTED_INVALID_NOTIFY_URL', 'description': 'Invalid notifyUrl', 'action': None},
          57: {'groupId': 5, 'name': 'REJECTED_INVALID_NOTIFY_CONTENT_TYPE', 'description': 'Invalid notifyContentType', 'action': None},
          58: {'groupId': 5, 'name': 'REJECTED_INVALID_DTMF_SIGN', 'description': 'Invalid repeatDtmf. Must be number, asterisk (*) or shark (#)', 'action': None},
          59: {'groupId': 5, 'name': 'REJECTED_INVALID_DTMF_TIMEOUT', 'description': 'Invalid dtmfTimeout. Must be positive number', 'action': None},
          60: {'groupId': 5, 'name': 'REJECTED_INVALID_RING_TIMEOUT', 'description':  'Invalid ringTimeout. Must be positive number', 'action': None},
          61: {'groupId': 5, 'name': 'REJECTED_INVALID_CALL_TIMEOUT', 'desciption': 'Invalid callTimeout. Must be positive number', 'action': None},
          62: {'groupId': 5, 'name': 'REJECTED_INVALID_MACHINE_DETECTION', 'description': 'Invalid machineDetection. Possible values: continue, hangup, disable', 'action': None},
          63: {'groupId': 5, 'name': 'REJECTED_INVALID_ACTIONS', 'description': 'Invalid actions. Must be JSON format', 'action': None},
          64: {'groupId': 5, 'name': 'REJECTED_INVALID_ACTION_GROUPS', 'description': 'Invalid actionGroups. Must be JSON format', 'action': None},
             }

for key, value in status_id.items():
    status_id[key].update(groupName = status_group[value['groupId']]['groupName'])

error_group = {
    0: {'groupName': 'OK', 'description': 'No error'},
    1: {'groupName': 'HANDSET_ERRORS', 'description': 'Handset error occured.'},
    2: {'groupName': 'USER_ERRORS', 'description': 'User error occured.'},
    3: {'groupName': 'OPERATOR_ERRORS', 'description': 'Operator error occured.'}
  }

error_id = {0: {'description': 'No Error',
  'groupId': 0,
  'name': 'NO_ERROR',
  'permanent': False},
 1: {'description': 'Unknown Subscriber',
  'groupId': 1,
  'name': 'EC_UNKNOWN_SUBSCRIBER',
  'permanent': True},
 5: {'description': 'Unidentified Subscriber',
  'groupId': 1,
  'name': 'EC_UNIDENTIFIED_SUBSCRIBER',
  'permanent': False},
 6: {'description': 'Absent Subscriber',
  'groupId': 1,
  'name': 'EC_ABSENT_SUBSCRIBER_SM',
  'permanent': False},
 9: {'description': 'Illegal Subscriber',
  'groupId': 1,
  'name': 'EC_ILLEGAL_SUBSCRIBER',
  'permanent': True},
 10: {'description': 'Bearer Service Not Provisioned',
  'groupId': 3,
  'name': 'EC_BEARER_SERVICE_NOT_PROVISIONED',
  'permanent': True},
 11: {'description': 'Teleservice Not Provisioned',
  'groupId': 1,
  'name': 'EC_TELESERVICE_NOT_PROVISIONED',
  'permanent': True},
 12: {'description': 'Illegal Equipment',
  'groupId': 1,
  'name': 'EC_ILLEGAL_EQUIPMENT',
  'permanent': True},
 13: {'description': 'Call Barred',
  'groupId': 1,
  'name': 'EC_CALL_BARRED',
  'permanent': False},
 20: {'description': 'SS Incompatibility',
  'groupId': 3,
  'name': 'EC_SS_INCOMPATIBILITY',
  'permanent': False},
 21: {'description': 'Facility Not Supported',
  'groupId': 1,
  'name': 'EC_FACILITY_NOT_SUPPORTED',
  'permanent': False},
 27: {'description': 'Absent Subscriber',
  'groupId': 1,
  'name': 'EC_ABSENT_SUBSCRIBER',
  'permanent': False},
 31: {'description': 'Subscriber Busy For Mt SMS',
  'groupId': 1,
  'name': 'EC_SUBSCRIBER_BUSY_FOR_MT_SMS',
  'permanent': False},
 32: {'description': 'SM Delivery Failure',
  'groupId': 1,
  'name': 'EC_SM_DELIVERY_FAILURE',
  'permanent': False},
 33: {'description': 'Message Waiting List Full',
  'groupId': 1,
  'name': 'EC_MESSAGE_WAITING_LIST_FULL',
  'permanent': False},
 34: {'description': 'System Failure',
  'groupId': 1,
  'name': 'EC_SYSTEM_FAILURE',
  'permanent': False},
 35: {'description': 'Data Missing',
  'groupId': 1,
  'name': 'EC_DATA_MISSING',
  'permanent': False},
 36: {'description': 'Unexpected Data Value',
  'groupId': 1,
  'name': 'EC_UNEXPECTED_DATA_VALUE',
  'permanent': False},
 51: {'description': 'Resource Limitation',
  'groupId': 3,
  'name': 'EC_RESOURCE_LIMITATION',
  'permanent': True},
 71: {'description': 'Unknown Alphabet',
  'groupId': 3,
  'name': 'EC_UNKNOWN_ALPHABET',
  'permanent': False},
 72: {'description': 'Ussd Busy',
  'groupId': 1,
  'name': 'EC_USSD_BUSY',
  'permanent': True},
 255: {'description': 'Unknown Error',
  'groupId': 1,
  'name': 'EC_UNKNOWN_ERROR',
  'permanent': False},
 256: {'description': 'SM DF Memory Capacity Exceeded',
  'groupId': 1,
  'name': 'EC_SM_DF_MEMORYCAPACITYEXCEEDED',
  'permanent': False},
 257: {'description': 'SM DF Equipment Protocol Error',
  'groupId': 1,
  'name': 'EC_SM_DF_EQUIPMENTPROTOCOLERROR',
  'permanent': False},
 258: {'description': 'SM DF Equipment Not SM Equipped',
  'groupId': 1,
  'name': 'EC_SM_DF_EQUIPMENTNOTSM_EQUIPPED',
  'permanent': False},
 259: {'description': 'SM DF Unknown Service Centre',
  'groupId': 1,
  'name': 'EC_SM_DF_UNKNOWNSERVICECENTRE',
  'permanent': False},
 260: {'description': 'SM DF Sc Congestion',
  'groupId': 1,
  'name': 'EC_SM_DF_SC_CONGESTION',
  'permanent': False},
 261: {'description': 'SM DF InvalidSME Address',
  'groupId': 1,
  'name': 'EC_SM_DF_INVALIDSME_ADDRESS',
  'permanent': False},
 262: {'description': 'SM DF Subscribernotsc Subscriber',
  'groupId': 1,
  'name': 'EC_SM_DF_SUBSCRIBERNOTSC_SUBSCRIBER',
  'permanent': False},
 500: {'description': 'Provider General Error',
  'groupId': 1,
  'name': 'EC_PROVIDER_GENERAL_ERROR',
  'permanent': False},
 501: {'description': 'Invalid Response Received',
  'groupId': 3,
  'name': 'EC_INVALID_RESPONSE_RECEIVED',
  'permanent': False},
 502: {'description': 'No Response',
  'groupId': 1,
  'name': 'EC_NO_RESPONSE',
  'permanent': False},
 503: {'description': 'Service Completion Failure',
  'groupId': 1,
  'name': 'EC_SERVICE_COMPLETION_FAILURE',
  'permanent': False},
 504: {'description': 'Unexpected Response From Peer',
  'groupId': 1,
  'name': 'EC_UNEXPECTED_RESPONSE_FROM_PEER',
  'permanent': False},
 507: {'description': 'Mistyped Parameter',
  'groupId': 1,
  'name': 'EC_MISTYPED_PARAMETER',
  'permanent': False},
 508: {'description': 'Supported Service',
  'groupId': 1,
  'name': 'EC_NOT_SUPPORTED_SERVICE',
  'permanent': False},
 509: {'description': 'Duplicated Invoke Id',
  'groupId': 1,
  'name': 'EC_DUPLICATED_INVOKE_ID',
  'permanent': False},
 511: {'description': 'Initiating Release',
  'groupId': 1,
  'name': 'EC_INITIATING_RELEASE',
  'permanent': True},
 1024: {'description': 'App Context Not Supported',
  'groupId': 1,
  'name': 'EC_OR_APPCONTEXTNOTSUPPORTED',
  'permanent': False},
 1025: {'description': 'Invalid Destination Reference',
  'groupId': 1,
  'name': 'EC_OR_INVALIDDESTINATIONREFERENCE',
  'permanent': False},
 1026: {'description': 'Invalid Originating Reference',
  'groupId': 1,
  'name': 'EC_OR_INVALIDORIGINATINGREFERENCE',
  'permanent': False},
 1027: {'description': 'Encapsulated AC Not Supported',
  'groupId': 1,
  'name': 'EC_OR_ENCAPSULATEDAC_NOTSUPPORTED',
  'permanent': False},
 1028: {'description': 'Transport Protection Not Adequate',
  'groupId': 1,
  'name': 'EC_OR_TRANSPORTPROTECTIONNOTADEQUATE',
  'permanent': False},
 1029: {'description': 'No Reason Given',
  'groupId': 1,
  'name': 'EC_OR_NOREASONGIVEN',
  'permanent': False},
 1030: {'description': 'Potential Version Incompatibility',
  'groupId': 1,
  'name': 'EC_OR_POTENTIALVERSIONINCOMPATIBILITY',
  'permanent': False},
 1031: {'description': 'Remote Node Not Reachable',
  'groupId': 1,
  'name': 'EC_OR_REMOTENODENOTREACHABLE',
  'permanent': False},
 1152: {'description': 'No Translation For An Address Of Such Nature',
  'groupId': 1,
  'name': 'EC_NNR_NOTRANSLATIONFORANADDRESSOFSUCHNATURE',
  'permanent': False},
 1153: {'description': 'No Translation For This Specific Address',
  'groupId': 1,
  'name': 'EC_NNR_NOTRANSLATIONFORTHISSPECIFICADDRESS',
  'permanent': False},
 1154: {'description': 'Subsystem Congestion',
  'groupId': 1,
  'name': 'EC_NNR_SUBSYSTEMCONGESTION',
  'permanent': False},
 1155: {'description': 'Subsystem Failure',
  'groupId': 1,
  'name': 'EC_NNR_SUBSYSTEMFAILURE',
  'permanent': False},
 1156: {'description': 'Unequipped User',
  'groupId': 1,
  'name': 'EC_NNR_UNEQUIPPEDUSER',
  'permanent': False},
 1157: {'description': 'MTP Failure',
  'groupId': 1,
  'name': 'EC_NNR_MTPFAILURE',
  'permanent': False},
 1158: {'description': 'Network Congestion',
  'groupId': 1,
  'name': 'EC_NNR_NETWORKCONGESTION',
  'permanent': False},
 1159: {'description': 'Unqualified',
  'groupId': 1,
  'name': 'EC_NNR_UNQUALIFIED',
  'permanent': False},
 1160: {'description': 'Error In Message Transport XUDT',
  'groupId': 1,
  'name': 'EC_NNR_ERRORINMESSAGETRANSPORTXUDT',
  'permanent': False},
 1161: {'description': 'Error In Local Processing XUDT',
  'groupId': 1,
  'name': 'EC_NNR_ERRORINLOCALPROCESSINGXUDT',
  'permanent': False},
 1162: {'description': 'Destination Cannot Perform Reassembly XUDT',
  'groupId': 1,
  'name': 'EC_NNR_DESTINATIONCANNOTPERFORMREASSEMBLYXUDT',
  'permanent': False},
 1163: {'description': 'SCCP Failure',
  'groupId': 1,
  'name': 'EC_NNR_SCCPFAILURE',
  'permanent': False},
 1164: {'description': 'Hop Counter Violation',
  'groupId': 1,
  'name': 'EC_NNR_HOPCOUNTERVIOLATION',
  'permanent': False},
 1165: {'description': 'Segmentation Not Supported',
  'groupId': 1,
  'name': 'EC_NNR_SEGMENTATIONNOTSUPPORTED',
  'permanent': False},
 1166: {'description': 'Segmentation Failure',
  'groupId': 1,
  'name': 'EC_NNR_SEGMENTATIONFAILURE',
  'permanent': False},
 1281: {'description': 'User Specific Reason',
  'groupId': 1,
  'name': 'EC_UA_USERSPECIFICREASON',
  'permanent': False},
 1282: {'description': 'User Resource Limitation',
  'groupId': 1,
  'name': 'EC_UA_USERRESOURCELIMITATION',
  'permanent': False},
 1283: {'description': 'Resource Unavailable',
  'groupId': 1,
  'name': 'EC_UA_RESOURCEUNAVAILABLE',
  'permanent': False},
 1284: {'description': 'Application Procedure Cancellation',
  'groupId': 1,
  'name': 'EC_UA_APPLICATIONPROCEDURECANCELLATION',
  'permanent': False},
 1536: {'description': 'Provider Malfunction',
  'groupId': 1,
  'name': 'EC_PA_PROVIDERMALFUNCTION',
  'permanent': False},
 1537: {'description': 'Supporting Dialog Or Transaction Realeased',
  'groupId': 1,
  'name': 'EC_PA_SUPPORTINGDIALOGORTRANSACTIONREALEASED',
  'permanent': False},
 1538: {'description': 'Ressource Limitation',
  'groupId': 1,
  'name': 'EC_PA_RESSOURCELIMITATION',
  'permanent': False},
 1539: {'description': 'Maintenance Activity',
  'groupId': 1,
  'name': 'EC_PA_MAINTENANCEACTIVITY',
  'permanent': False},
 1540: {'description': 'Version Incompatibility',
  'groupId': 1,
  'name': 'EC_PA_VERSIONINCOMPATIBILITY',
  'permanent': False},
 1541: {'description': 'Abnormal Map Dialog',
  'groupId': 1,
  'name': 'EC_PA_ABNORMALMAPDIALOG',
  'permanent': False},
 1792: {'description': 'Abnormal Event Detected By Peer',
  'groupId': 1,
  'name': 'EC_NC_ABNORMALEVENTDETECTEDBYPEER',
  'permanent': False},
 1793: {'description': 'Response Rejected By Peer',
  'groupId': 1,
  'name': 'EC_NC_RESPONSEREJECTEDBYPEER',
  'permanent': False},
 1794: {'description': 'Abnormal Event Received From Peer',
  'groupId': 1,
  'name': 'EC_NC_ABNORMALEVENTRECEIVEDFROMPEER',
  'permanent': False},
 1795: {'description': 'Message Cannot Be Delivered To Peer',
  'groupId': 1,
  'name': 'EC_NC_MESSAGECANNOTBEDELIVEREDTOPEER',
  'permanent': False},
 1796: {'description': 'Provider Out Of Invoke',
  'groupId': 1,
  'name': 'EC_NC_PROVIDEROUTOFINVOKE',
  'permanent': False},
 2048: {'description': 'Time Out',
  'groupId': 3,
  'name': 'EC_TIME_OUT',
  'permanent': False},
 2049: {'description': 'IMSI blacklisted',
  'groupId': 2,
  'name': 'EC_IMSI_BLACKLISTED',
  'permanent': True},
 2050: {'description': 'DND blacklisted',
  'groupId': 3,
  'name': 'EC_DEST_ADDRESS_BLACKLISTED',
  'permanent': True},
 2051: {'description': 'Text blacklisted',
  'groupId': 3,
  'name': 'EC_INVALIDMSCADDRESS',
  'permanent': False},
 4096: {'description': 'Invalid PDU Format',
  'groupId': 2,
  'name': 'EC_INVALID_PDU_FORMAT',
  'permanent': True},
 4097: {'description': 'Not Submitted To GMSC',
  'groupId': 3,
  'name': 'EC_NOTSUBMITTEDTOGMSC',
  'permanent': False},
 4100: {'description': 'Message canceled',
  'groupId': 2,
  'name': 'EC_MESSAGE_CANCELED',
  'permanent': True},
 4101: {'description': 'Validity Expired',
  'groupId': 2,
  'name': 'EC_VALIDITYEXPIRED',
  'permanent': True},
 4102: {'description': 'Not Submitted To Smpp Channel',
  'groupId': 3,
  'name': 'EC_NOTSUBMITTEDTOSMPPCHANNEL',
  'permanent': True},
 5000: {'description': 'Call answered by human',
  'groupId': 0,
  'name': 'VOICE_ANSWERED',
  'permanent': True},
 5001: {'description': 'Call answered by machine',
  'groupId': 0,
  'name': 'VOICE_ANSWERED_MACHINE',
  'permanent': True},
 5002: {'description': 'User was busy during call attempt',
  'groupId': 2,
  'name': 'EC_VOICE_USER_BUSY',
  'permanent': True},
 5003: {'description': 'User was notified, but did not answer call',
  'groupId': 2,
  'name': 'EC_VOICE_NO_ANSWER',
  'permanent': True},
 5004: {'description': 'File provided for call could not be downloaded',
  'groupId': 2,
  'name': 'EC_VOICE_ERROR_DOWNLOADING_FILE',
  'permanent': True},
 5005: {'description': 'Format of file provided for call is not supported',
  'groupId': 2,
  'name': 'EC_VOICE_ERROR_UNSUPPORTED_AUDIO_FORMAT',
  'permanent': True},
 5400: {'description': 'The request could not be understood due to malformed syntax',
  'groupId': 3,
  'name': 'EC_VOICE_ERROR_BAD_REQUEST',
  'permanent': False},
 5403: {'description': 'The server understood the request, but is refusing to fulfil it',
  'groupId': 3,
  'name': 'EC_VOICE_ERROR_BAD_REQUEST',
  'permanent': False},
 5404: {'description': 'The server has definitive information that the user does not exist at the domain specified in the Request-URI',
  'groupId': 3,
  'name': 'EC_VOICE_ERROR_DESTINATION_NOT_FOUND',
  'permanent': False},
 5407: {'description': 'The request requires user authentication',
  'groupId': 3,
  'name': 'EC_VOICE_ERROR_PROXY_AUTHENTICATION_REQUIRED',
  'permanent': False},
 5408: {'description': 'Could not find the user in time',
  'groupId': 3,
  'name': 'EC_VOICE_ERROR_BAD_REQUEST',
  'permanent': False},
  5410: {'description': 'The user existed once, but is not available here any more',
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_GONE',
   'permanent': False},
  5414: {'description': 'The server is refusing to service the request because the Request-URI is longer than the server is willing to interpret',
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_REQUEST_URI_TOO_LONG',
   'permanent': False},
  5415: {'description': 'Request body in a format not supported',
   'groupId': 3,
   'name': 'EC_VOICE_UNSUPPORTED_MEDIA_TYPE',
   'permanent': False},
  5480: {'description': 'Callee currently unavailable',
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_TEMPORARILY_NOT_AVAILABE',
   'permanent': False},
  5484: {'description': 'Request-URI incomplete',
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_ADDRESS_INCOMPLETE',
   'permanent': False},
  5487: {'description': 'Request has terminated by bye or cancel',
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_BAD_REQUEST',
   'permanent': False},
  5488: {'description': 'Some aspect of the session description or the Request-URI is not acceptable',
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_NOT_ACCEPTABLE_HERE',
   'permanent': False},
  5491: {'description': 'Server has some pending request from the same dialog', 
   'groupId': 3,
   'name': 'EC_VOICE_ERROR_BAD_REQUEST',
   'permanent': False},
  5492: {'description': 'Same text already sent to destination',
   'groupId': 3,
   'name': 'EC_DUPLICATE_MESSAGE',
   'permanent': True} 
}
